@@ -15,19 +15,29 @@ class Mongo:
         aws_secret_access_key,
         mongo_cluster,
         max_pool_size=64,
+        **kwargs,
     ):
         access_key_id = quote_plus(aws_access_key_id)
         secret_access_key = quote_plus(aws_secret_access_key)
         cluster = quote_plus(mongo_cluster)
 
-        uri = "mongodb+srv://%s:%s@%s/?authSource=$external&authMechanism=MONGODB-AWS&retryWrites=true&w=majority&readConcernLevel=majority&readPreference=secondaryPreferred" % (
-            access_key_id,
-            secret_access_key,
-            cluster,
+        uri = (
+            "mongodb+srv://%s:%s@%s/"
+            % (
+                access_key_id,
+                secret_access_key,
+                cluster,
+            )
+            + "?authSource=$external"
+            + "&authMechanism=MONGODB-AWS"
+            + "&retryWrites=true"
+            + "&w=majority"
+            + "&readConcernLevel=majority"
+            + "&readPreference=secondaryPreferred"
         )
 
         try:
-            self.client = MongoClient(uri, maxPoolSize=max_pool_size)
+            self.client = MongoClient(uri, maxPoolSize=max_pool_size, **kwargs)
         except Exception as err:
             raise Exception("ERROR - Connection to MongoClient:", err)
 
