@@ -377,7 +377,7 @@ class SagemakerFeatureStore:
             cursor = "0"
             while cursor != 0:
                 cursor, keys = self.redis_client.scan(
-                    cursor=cursor, match=f"{feature_group_name}:*", count=3200
+                    cursor=cursor, match=f"{{{feature_group_name}}}:*", count=3200
                 )
                 if keys:
                     self.redis_client.delete(*keys)
@@ -466,13 +466,13 @@ class SagemakerFeatureStore:
             pipe = self.redis_client.pipeline()
 
             if not features_list:
-                key_name = "{}:{}".format(
+                key_name = "{{{}}}:{}".format(
                     feature_group_name, record_identifiers_list[0]
                 )
                 features_list = self.redis_client.hkeys(key_name)
 
             for record_identifier in record_identifiers_list:
-                key_name = "{}:{}".format(feature_group_name, record_identifier)
+                key_name = "{{{}}}:{}".format(feature_group_name, record_identifier)
                 pipe.hmget(key_name, features_list)
             results = pipe.execute()
 
@@ -613,7 +613,7 @@ class SagemakerFeatureStore:
 
                     # Ingest to Redis online store
                     if is_redis:
-                        key_name = "{}:{}".format(
+                        key_name = "{{{}}}:{}".format(
                             feature_group_name, str(row[record_identifier])
                         )
                         # convert to empty string if value is None
@@ -622,7 +622,8 @@ class SagemakerFeatureStore:
                             for column in row.__fields__
                         }
                         pipe.hmset(key_name, mapping)
-                        pipe.expire(key_name, 259200)
+                        # expire for 7 days
+                        pipe.expire(key_name, 604800)
 
                         ops = ops + 1
                         if ops == ops_limit:
@@ -747,7 +748,7 @@ class SagemakerFeatureStore:
 
             # Ingest to Redis
             if is_redis:
-                key_name = "{}:{}".format(
+                key_name = "{{{}}}:{}".format(
                     feature_group_name, str(record[record_identifier])
                 )
                 for key, value in record.items():
@@ -761,7 +762,8 @@ class SagemakerFeatureStore:
                     elif value is None:
                         record[key] = ""
                 pipe.hmset(key_name, record)
-                pipe.expire(key_name, 259200)
+                # Expire for 7 days
+                pipe.expire(key_name, 604800)
         if is_redis:
             pipe.execute()
             print("Done writing to redis")
@@ -1062,7 +1064,9 @@ class SagemakerFeatureStore:
 
         ops = 0
         for i, row in enumerate(df_dict):
-            key_name = "{}:{}".format(feature_group_name, row[record_identifier_name])
+            key_name = "{{{}}}:{}".format(
+                feature_group_name, row[record_identifier_name]
+            )
             for key, value in row.items():
                 if type(value) == bool:
                     if value:
@@ -1073,7 +1077,7 @@ class SagemakerFeatureStore:
                 elif value is None:
                     row[key] = ""
             pipe.hmset(key_name, row)
-            pipe.expire(key_name, 259200)
+            pipe.expire(key_name, 604800)
 
             ops = ops + 1
             if ops == ops_limit:
